Merge pull request #813 from njh/openldap_symbol_fix
[collectd.git] / src / cpu.c
index 91dfade..03d8e6f 100644 (file)
--- a/src/cpu.c
+++ b/src/cpu.c
@@ -97,8 +97,8 @@
 #define CPU_STATE_SOFTIRQ 6
 #define CPU_STATE_STEAL 7
 #define CPU_STATE_IDLE 8
-#define CPU_STATE_ACTIVE 9 /* sum of (!idle) */
-#define CPU_STATE_MAX 10 /* #states */
+#define CPU_STATE_COLLECTD_ACTIVE 9 /* sum of (!idle) */
+#define CPU_STATE_COLLECTD_MAX 10 /* #states */
 
 #if HAVE_STATGRAB_H
 # include <statgrab.h>
@@ -131,12 +131,6 @@ static const char *cpu_state_names[] = {
 static mach_port_t port_host;
 static processor_port_array_t cpu_list;
 static mach_msg_type_number_t cpu_list_len;
-
-#if PROCESSOR_TEMPERATURE
-static int cpu_temp_retry_counter = 0;
-static int cpu_temp_retry_step    = 1;
-static int cpu_temp_retry_max     = 1;
-#endif /* PROCESSOR_TEMPERATURE */
 /* #endif PROCESSOR_CPU_LOAD_INFO */
 
 #elif defined(KERNEL_LINUX)
@@ -222,7 +216,7 @@ static int cpu_config (char const *key, char const *value) /* {{{ */
 
 static int init (void)
 {
-#if PROCESSOR_CPU_LOAD_INFO || PROCESSOR_TEMPERATURE
+#if PROCESSOR_CPU_LOAD_INFO
        kern_return_t status;
 
        port_host = mach_host_self ();
@@ -368,7 +362,7 @@ static int cpu_states_alloc (size_t cpu_num) /* {{{ */
        cpu_state_t *tmp;
        size_t sz;
 
-       sz = (((size_t) cpu_num) + 1) * CPU_STATE_MAX;
+       sz = (((size_t) cpu_num) + 1) * CPU_STATE_COLLECTD_MAX;
        assert (sz > 0);
 
        /* We already have enough space. */
@@ -391,7 +385,7 @@ static int cpu_states_alloc (size_t cpu_num) /* {{{ */
 
 static cpu_state_t *get_cpu_state (size_t cpu_num, size_t state) /* {{{ */
 {
-       size_t index = ((cpu_num * CPU_STATE_MAX) + state);
+       size_t index = ((cpu_num * CPU_STATE_COLLECTD_MAX) + state);
 
        if (index >= cpu_states_num)
                return (NULL);
@@ -399,58 +393,58 @@ static cpu_state_t *get_cpu_state (size_t cpu_num, size_t state) /* {{{ */
        return (&cpu_states[index]);
 } /* }}} cpu_state_t *get_cpu_state */
 
/* Populates the per-CPU CPU_STATE_ACTIVE rate and the global rate_by_state
  * array. */
 static void aggregate (gauge_t *sum_by_state) /* {{{ */
 {
        size_t cpu_num;
        size_t state;
 
-       for (state = 0; state < CPU_STATE_MAX; state++)
+       for (state = 0; state < CPU_STATE_COLLECTD_MAX; state++)
                sum_by_state[state] = NAN;
 
        for (cpu_num = 0; cpu_num < global_cpu_num; cpu_num++)
        {
                cpu_state_t *this_cpu_states = get_cpu_state (cpu_num, 0);
 
-               this_cpu_states[CPU_STATE_ACTIVE].rate = NAN;
+               this_cpu_states[CPU_STATE_COLLECTD_ACTIVE].rate = NAN;
 
-               for (state = 0; state < CPU_STATE_ACTIVE; state++)
+               for (state = 0; state < CPU_STATE_COLLECTD_ACTIVE; state++)
                {
                        if (!this_cpu_states[state].has_value)
                                continue;
 
                        RATE_ADD (sum_by_state[state], this_cpu_states[state].rate);
                        if (state != CPU_STATE_IDLE)
-                               RATE_ADD (this_cpu_states[CPU_STATE_ACTIVE].rate, this_cpu_states[state].rate);
+                               RATE_ADD (this_cpu_states[CPU_STATE_COLLECTD_ACTIVE].rate, this_cpu_states[state].rate);
                }
 
-               RATE_ADD (sum_by_state[CPU_STATE_ACTIVE], this_cpu_states[CPU_STATE_ACTIVE].rate);
+               RATE_ADD (sum_by_state[CPU_STATE_COLLECTD_ACTIVE], this_cpu_states[CPU_STATE_COLLECTD_ACTIVE].rate);
        }
 } /* }}} void aggregate */
 
 /* Commits (dispatches) the values for one CPU or the global aggregation.
  * cpu_num is the index of the CPU to be committed or -1 in case of the global
* aggregation. rates is a pointer to CPU_STATE_MAX gauge_t values holding the
  * current rate; each rate may be NAN. Calculates the percentage of each state
  * and dispatches the metric. */
 static void cpu_commit_one (int cpu_num, /* {{{ */
-               gauge_t rates[static CPU_STATE_MAX])
+               gauge_t rates[static CPU_STATE_COLLECTD_MAX])
 {
        size_t state;
        gauge_t sum;
 
-       sum = rates[CPU_STATE_ACTIVE];
+       sum = rates[CPU_STATE_COLLECTD_ACTIVE];
        RATE_ADD (sum, rates[CPU_STATE_IDLE]);
 
        if (!report_by_state)
        {
-               gauge_t percent = 100.0 * rates[CPU_STATE_ACTIVE] / sum;
-               submit_percent (cpu_num, CPU_STATE_ACTIVE, percent);
+               gauge_t percent = 100.0 * rates[CPU_STATE_COLLECTD_ACTIVE] / sum;
+               submit_percent (cpu_num, CPU_STATE_COLLECTD_ACTIVE, percent);
                return;
        }
 
-       for (state = 0; state < CPU_STATE_ACTIVE; state++)
+       for (state = 0; state < CPU_STATE_COLLECTD_ACTIVE; state++)
        {
                gauge_t percent = 100.0 * rates[state] / sum;
                submit_percent (cpu_num, state, percent);
@@ -474,32 +468,32 @@ static void cpu_commit_without_aggregation (void) /* {{{ */
 {
        int state;
 
-       for (state = 0; state < CPU_STATE_ACTIVE; state++)
+       for (state = 0; state < CPU_STATE_COLLECTD_ACTIVE; state++)
        {
                size_t cpu_num;
                if (report_by_cpu) {
-               for (cpu_num = 0; cpu_num < global_cpu_num; cpu_num++)
-               {
-                       cpu_state_t *s = get_cpu_state (cpu_num, state);
+                       for (cpu_num = 0; cpu_num < global_cpu_num; cpu_num++)
+                       {
+                               cpu_state_t *s = get_cpu_state (cpu_num, state);
 
-                       if (!s->has_value)
-                               continue;
+                               if (!s->has_value)
+                                       continue;
 
-                       submit_derive ((int) cpu_num, (int) state, s->conv.last_value.derive);
-               }
+                               submit_derive ((int) cpu_num, (int) state, s->conv.last_value.derive);
+                       }
                } else {
-               derive_t derive_total = 0;
-               for (cpu_num = 0; cpu_num < global_cpu_num; cpu_num++)
-               {
-                       cpu_state_t *s = get_cpu_state (cpu_num, state);
+                       derive_t derive_total = 0;
+                       for (cpu_num = 0; cpu_num < global_cpu_num; cpu_num++)
+                               {
+                                       cpu_state_t *s = get_cpu_state (cpu_num, state);
 
-                       if (!s->has_value)
-                               continue;
+                                       if (!s->has_value)
+                                               continue;
 
-                       derive_total += s->conv.last_value.derive;
-                       
-               }
-               submit_derive (-1, (int) state, derive_total);
+                                       derive_total += s->conv.last_value.derive;
+
+                               }
+                       submit_derive (-1, (int) state, derive_total);
                }
        }
 } /* }}} void cpu_commit_without_aggregation */
@@ -507,7 +501,7 @@ static void cpu_commit_without_aggregation (void) /* {{{ */
 /* Aggregates the internal state and dispatches the metrics. */
 static void cpu_commit (void) /* {{{ */
 {
-       gauge_t global_rates[CPU_STATE_MAX] = {
+       gauge_t global_rates[CPU_STATE_COLLECTD_MAX] = {
                NAN, NAN, NAN, NAN, NAN, NAN, NAN, NAN, NAN, NAN
        };
        size_t cpu_num;
@@ -529,12 +523,12 @@ static void cpu_commit (void) /* {{{ */
        for (cpu_num = 0; cpu_num < global_cpu_num; cpu_num++)
        {
                cpu_state_t *this_cpu_states = get_cpu_state (cpu_num, 0);
-               gauge_t local_rates[CPU_STATE_MAX] = {
+               gauge_t local_rates[CPU_STATE_COLLECTD_MAX] = {
                        NAN, NAN, NAN, NAN, NAN, NAN, NAN, NAN, NAN, NAN
                };
                size_t state;
 
-               for (state = 0; state < CPU_STATE_ACTIVE; state++)
+               for (state = 0; state < CPU_STATE_COLLECTD_ACTIVE; state++)
                        if (this_cpu_states[state].has_value)
                                local_rates[state] = this_cpu_states[state].rate;
 
@@ -551,7 +545,7 @@ static int cpu_stage (size_t cpu_num, size_t state, derive_t value, cdtime_t now
        cpu_state_t *s;
        value_t v;
 
-       if (state >= CPU_STATE_ACTIVE)
+       if (state >= CPU_STATE_COLLECTD_ACTIVE)
                return (EINVAL);
 
        status = cpu_states_alloc (cpu_num);
@@ -577,37 +571,31 @@ static int cpu_read (void)
 {
        cdtime_t now = cdtime ();
 
-#if PROCESSOR_CPU_LOAD_INFO || PROCESSOR_TEMPERATURE /* {{{ */
+#if PROCESSOR_CPU_LOAD_INFO /* {{{ */
        int cpu;
 
        kern_return_t status;
 
-#if PROCESSOR_CPU_LOAD_INFO
        processor_cpu_load_info_data_t cpu_info;
        mach_msg_type_number_t         cpu_info_len;
-#endif
-#if PROCESSOR_TEMPERATURE
-       processor_info_data_t          cpu_temp;
-       mach_msg_type_number_t         cpu_temp_len;
-#endif
 
        host_t cpu_host;
 
        for (cpu = 0; cpu < cpu_list_len; cpu++)
        {
-#if PROCESSOR_CPU_LOAD_INFO
                cpu_host = 0;
                cpu_info_len = PROCESSOR_BASIC_INFO_COUNT;
 
-               if ((status = processor_info (cpu_list[cpu],
-                                               PROCESSOR_CPU_LOAD_INFO, &cpu_host,
-                                               (processor_info_t) &cpu_info, &cpu_info_len)) != KERN_SUCCESS)
+               status = processor_info (cpu_list[cpu], PROCESSOR_CPU_LOAD_INFO, &cpu_host,
+                               (processor_info_t) &cpu_info, &cpu_info_len);
+               if (status != KERN_SUCCESS)
                {
-                       ERROR ("cpu plugin: processor_info failed with status %i", (int) status);
+                       ERROR ("cpu plugin: processor_info (PROCESSOR_CPU_LOAD_INFO) failed: %s",
+                                       mach_error_string (status));
                        continue;
                }
 
-               if (cpu_info_len < CPU_STATE_MAX)
+               if (cpu_info_len < CPU_STATE_COLLECTD_MAX)
                {
                        ERROR ("cpu plugin: processor_info returned only %i elements..", cpu_info_len);
                        continue;
@@ -617,50 +605,6 @@ static int cpu_read (void)
                cpu_stage (cpu, CPU_STATE_NICE,   (derive_t) cpu_info.cpu_ticks[CPU_STATE_NICE],   now);
                cpu_stage (cpu, CPU_STATE_SYSTEM, (derive_t) cpu_info.cpu_ticks[CPU_STATE_SYSTEM], now);
                cpu_stage (cpu, CPU_STATE_IDLE,   (derive_t) cpu_info.cpu_ticks[CPU_STATE_IDLE],   now);
-#endif /* PROCESSOR_CPU_LOAD_INFO */
-
-#if PROCESSOR_TEMPERATURE
-               /*
-                * Not all Apple computers do have this ability. To minimize
-                * the messages sent to the syslog we do an exponential
-                * stepback if `processor_info' fails. We still try ~once a day
-                * though..
-                */
-               if (cpu_temp_retry_counter > 0)
-               {
-                       cpu_temp_retry_counter--;
-                       continue;
-               }
-
-               cpu_temp_len = PROCESSOR_INFO_MAX;
-
-               status = processor_info (cpu_list[cpu],
-                               PROCESSOR_TEMPERATURE,
-                               &cpu_host,
-                               cpu_temp, &cpu_temp_len);
-               if (status != KERN_SUCCESS)
-               {
-                       ERROR ("cpu plugin: processor_info failed: %s",
-                                       mach_error_string (status));
-
-                       cpu_temp_retry_counter = cpu_temp_retry_step;
-                       cpu_temp_retry_step *= 2;
-                       if (cpu_temp_retry_step > cpu_temp_retry_max)
-                               cpu_temp_retry_step = cpu_temp_retry_max;
-
-                       continue;
-               }
-
-               if (cpu_temp_len != 1)
-               {
-                       DEBUG ("processor_info (PROCESSOR_TEMPERATURE) returned %i elements..?",
-                                       (int) cpu_temp_len);
-                       continue;
-               }
-
-               cpu_temp_retry_counter = 0;
-               cpu_temp_retry_step    = 1;
-#endif /* PROCESSOR_TEMPERATURE */
        }
 /* }}} #endif PROCESSOR_CPU_LOAD_INFO */
@@ -399,58 +393,58 @@ static cpu_state_t *get_cpu_state (size_t cpu_num, size_t state) /* {{{ */
 } /* }}} cpu_state_t *get_cpu_state */
 
-/* Populates the per-CPU CPU_STATE_ACTIVE rate and the global rate_by_state
+/* Populates the per-CPU CPU_STATE_COLLECTD_ACTIVE rate and the global rate_by_state
  * array. */
 static void aggregate (gauge_t *sum_by_state) /* {{{ */
@@ -399,58 +393,58 @@ static cpu_state_t *get_cpu_state (size_t cpu_num, size_t state) /* {{{ */
 /* Commits (dispatches) the values for one CPU or the global aggregation.
  * cpu_num is the index of the CPU to be committed or -1 in case of the global
- * aggregation. rates is a pointer to CPU_STATE_MAX gauge_t values holding the
+ * aggregation. rates is a pointer to CPU_STATE_COLLECTD_MAX gauge_t values holding the
  * current rate; each rate may be NAN. Calculates the percentage of each state
  * and dispatches the metric. */